@@ -26,14 +26,15 @@
 
 class AnalyIA64Disassembler: public AnalyDisassembler {
 public:
-			void			init(Analyser *A);
-	virtual   void	     	done();
-	virtual	OBJECT_ID		object_id() const;
+					AnalyIA64Disassembler() {};
+					AnalyIA64Disassembler(BuildCtorArg&a): AnalyDisassembler(a) {};
+		void			init(Analyser *A);
+	virtual	ObjectID		getObjectID() const;
 
-	virtual	Address		*branchAddr(OPCODE *opcode, branch_enum_t branchtype, bool examine);
-			Address		*createAddress(dword offset);
+	virtual	Address			*branchAddr(OPCODE *opcode, branch_enum_t branchtype, bool examine);
+		Address			*createAddress(uint32 offset);
 	virtual	void			examineOpcode(OPCODE *opcode);
-	virtual	branch_enum_t 	isBranch(OPCODE *opcode);
+	virtual	branch_enum_t 		isBranch(OPCODE *opcode);
 };
 
 #endif
