@@ -301,6 +301,8 @@ static bool blockop_func_eval(eval_scalar *result, char *name, eval_scalarlist *
 	/* FIXME: non-constant funcs (e.g. rand()) should
 	   set blockop_expr_is_const to false */
 	eval_func myfuncs[] = {
+		{"i", 0, {SCALAR_INT}, "iteration index"},
+		{"o", 0, {SCALAR_INT}, "current offset"},
 		{"readbyte", (void*)&func_readbyte, {SCALAR_INT}, "read byte from offset"},
 		{"read16le", (void*)&func_read16le, {SCALAR_INT}, "read little endian 16 bit word from offset"},
 		{"read32le", (void*)&func_read32le, {SCALAR_INT}, "read little endian 32 bit word from offset"},
@@ -308,7 +310,7 @@ static bool blockop_func_eval(eval_scalar *result, char *name, eval_scalarlist *
 		{"read16be", (void*)&func_read16be, {SCALAR_INT}, "read big endian 16 bit word from offset"},
 		{"read32be", (void*)&func_read32be, {SCALAR_INT}, "read big endian 32 bit word from offset"},
 		{"read64be", (void*)&func_read64be, {SCALAR_INT}, "read big endian 64 bit word from offset"},
-		{"readstring", (void*)&func_readstring, {SCALAR_INT, SCALAR_INT}},
+		{"readstring", (void*)&func_readstring, {SCALAR_INT, SCALAR_INT}, "read string (offset, length)"},
 		{NULL}
 	};
 	
@@ -369,6 +371,7 @@ Object *create_blockop_str_context(File *file, FileOfs ofs, uint len, uint size,
 		const char *s;
 		int p;
 		get_eval_error(&s, &p);
+		delete ctx;
 		throw MsgfException("error evaluating '%s': %s at %d", action, s, p);
 	}
 
@@ -491,6 +494,7 @@ Object *create_blockop_int_context(File *file, FileOfs ofs, uint len, uint size,
 		const char *s;
 		int p;
 		get_eval_error(&s, &p);
+		delete ctx;
 		throw MsgfException("error evaluating '%s': %s at %d", action, s, p);
 	}
 
