@@ -240,6 +240,16 @@ typedef uint16 elf64_quarter;
 #define ELF_EM_METAG	174	/* Imagination Technologies META processor architecture */
 #define ELF_EM_MCST_ELBRUS	175	/* MCST Elbrus general purpose hardware architecture */
 #define ELF_EM_ECOG16	176	/* Cyan Technology eCOG16 family */
+#define ELF_EM_CR16	177	/* National Semiconductor CompactRISC 16-bit processor */
+#define ELF_EM_ETPU	178	/* Freescale Extended Time Processing Unit */
+#define ELF_EM_SLE9X	179	/* Infineon Technologies SLE9X core */
+#define ELF_EM_L1OM	180	/* Intel L1OM */
+#define ELF_EM_K1OM	181	/* Intel K1OM */
+#define ELF_EM_INTEL182	182	/* Reserved by Intel */
+#define ELF_EM_AARCH64	183	/* ARM 64-bit architecture */
+#define ELF_EM_ARM184	184	/* Reserved by ARM */
+#define EFL_EM_AVR32	185	/* Atmel Corporation 32-bit microprocessor family */
+#define ELF_EM_ALPHA    0x9026
 
 
 /* e_version */
@@ -453,6 +463,23 @@ struct ELF_SYMBOL64 {
 #define ELF_R_386_GOTOFF		9
 #define ELF_R_386_GOTPC			10
 
+#define ELF_R_X86_64_NONE		0
+#define ELF_R_X86_64_64			1
+#define ELF_R_X86_64_PC32		2
+#define ELF_R_X86_64_GOT32		3
+#define ELF_R_X86_64_PLT32		4
+#define ELF_R_X86_64_COPY		5
+#define ELF_R_X86_64_GLOB_DAT		6
+#define ELF_R_X86_64_JUMP_SLOT		7
+#define ELF_R_X86_64_RELATIVE		8
+#define ELF_R_X86_64_GOTPCREL		9
+#define ELF_R_X86_64_32			10
+#define ELF_R_X86_64_32S		11
+#define ELF_R_X86_64_16			12
+#define ELF_R_X86_64_PC16		13
+#define ELF_R_X86_64_8			14
+#define ELF_R_X86_64_PC8		15
+
 struct ELF_REL32 {
 	elf32_addr	r_offset;
 	elf32_word	r_info;
@@ -460,7 +487,13 @@ struct ELF_REL32 {
 
 struct ELF_REL64 {
 	elf64_addr	r_offset;
-	elf64_word	r_info;
+	union {
+		elf64_word	r_info;
+		struct {
+			elf64_half r_type;
+			elf64_half r_sym;
+		};
+	};
 } PACKED;
 
 struct ELF_RELA32 {
@@ -471,7 +504,13 @@ struct ELF_RELA32 {
 
 struct ELF_RELA64 {
 	elf64_addr	r_offset;
-	elf64_word	r_info;
+	union {
+		elf64_word	r_info;
+		struct {
+			elf64_half r_type;
+			elf64_half r_sym;
+		};
+	};
 	elf64_sword	r_addend;
 } PACKED;
 
