@@ -115,7 +115,7 @@ class CallChain: public ht_treeview {
 		Analyser		*analy;
 		CallChainNode *root;
 public:
-			   void	init(Bounds *b, Analyser *analy, Address *a, char *desc);
+			void	init(Bounds *b, Analyser *analy, Address *a, char *desc);
 		virtual void	done();
 		virtual void	adjust(void *node, bool expand);
 		virtual void   *get_child(void *node, int i);
@@ -126,9 +126,10 @@ public:
 		virtual bool	has_children(void *node);
 		virtual bool	is_expanded(void *node);
 		virtual void	select_node(void *node);
+		CallChainNode   *get_current_node();
 private:
 	CallChainNode		*createNode(Address *a);
-			void		examineNode(CallChainNode *n);
+		void		examineNode(CallChainNode *n);
 };
 /*
  *
@@ -171,7 +172,7 @@ public:
 	virtual	bool	convert_ofs_to_id(const FileOfs offset, LINE_ID *line_id);
 	virtual	bool	closest_line_id(LINE_ID *line_id);
 	virtual	void	first_line_id(LINE_ID *line_id);
-	virtual	bool	getline(char *line, const LINE_ID line_id);
+	virtual	bool	getline(char *line, int maxlen, const LINE_ID line_id);
 	virtual	void	last_line_id(LINE_ID *line_id);
 	virtual	int	next_line_id(LINE_ID *line_id, int n);
 	virtual	int	prev_line_id(LINE_ID *line_id, int n);
@@ -207,6 +208,7 @@ public:
 	virtual	bool get_current_offset(FileOfs *ofs);
 	virtual	int  get_pindicator_str(char *buf, int max_len);
 	virtual	bool get_hscrollbar_pos(int *pstart, int *psize);
+	virtual	void getminbounds(int *width, int *height);
 		bool gotoAddress(Address *a, ht_view *source_object);
 	virtual	void handlemsg(htmsg *msg);
 	virtual	bool idle();
