@@ -34,8 +34,8 @@ extern format_viewer_if htcoffimage_if;
 class ht_coff_aviewer: public ht_aviewer {
 public:
 	ht_coff_shared_data *coff_shared;
-	ht_streamfile *file;
-		   void init(bounds *b, char *desc, int caps, ht_streamfile *file, ht_format_group *format_group, Analyser *analyser, ht_coff_shared_data *coff_shared);
+	File *file;
+		void init(Bounds *b, const char *desc, int caps, File *file, ht_format_group *format_group, Analyser *analyser, ht_coff_shared_data *coff_shared);
 	virtual void setAnalyser(Analyser *a);
 };
 #endif /* !__HTCOFFIMG_H__ */
