@@ -34,15 +34,14 @@ extern format_viewer_if htfinfo_if;
  
 class ht_finfo_text: public ht_statictext {
 protected:
-	ht_streamfile *file;
-	char finfotext[1024];
-	char *olddesc;
+	File *file;
+	const char *olddesc;
 	
 public:
-			void	init(bounds *b, ht_streamfile *file);
+		void	init(Bounds *b, File *file);
 	virtual	void	done();
 /* overwritten */
-	virtual	char *gettext();
+	virtual	int     gettext(char *text, int max_len);
 };
 
 #endif /* __HTFINFO_H__ */
