@@ -20,10 +20,10 @@
 
 #include "formats.h"
 #include "htapp.h"
-#include "htatom.h"
+#include "atom.h"
 #include "htcoff.h"
 #include "htctrl.h"
-#include "htendian.h"
+#include "endianess.h"
 #include "hthex.h"
 #include "htiobox.h"
 #include "htnewexe.h"
@@ -31,7 +31,7 @@
 #include "htpehead.h"
 #include "htpeil.h"
 #include "httag.h"
-#include "htstring.h"
+#include "strtools.h"
 #include "snprintf.h"
 
 #include "pestruct.h"
@@ -47,6 +47,18 @@ static ht_mask_ptable il_directory[] = {
 	{"metadata rva",   STATICTAG_EDIT_DWORD_LE("00000008")},
 	{"metadata size",  STATICTAG_EDIT_DWORD_LE("0000000c")},
 	{"attributes",     STATICTAG_EDIT_DWORD_LE("00000010")},
+	{"entrypoint token",STATICTAG_EDIT_DWORD_LE("00000014")},
+	{"resources rva",   STATICTAG_EDIT_DWORD_LE("00000018")},
+	{"resources size",  STATICTAG_EDIT_DWORD_LE("0000001c")},
+	{"strong name sig",  STATICTAG_EDIT_DWORD_LE("00000020")},
+	{"strong name sig",  STATICTAG_EDIT_DWORD_LE("00000024")},
+	{"code manager rva",   STATICTAG_EDIT_DWORD_LE("00000028")},
+	{"code manager size",  STATICTAG_EDIT_DWORD_LE("0000002c")},
+	{"vtable fixups rva",   STATICTAG_EDIT_DWORD_LE("00000030")},
+	{"vtable fixups size",   STATICTAG_EDIT_DWORD_LE("00000034")},
+	{"export address table",  STATICTAG_EDIT_DWORD_LE("00000038")},
+	{"export address table",  STATICTAG_EDIT_DWORD_LE("0000003c")},
+	{"managed native header", STATICTAG_EDIT_DWORD_LE("00000040")},
 	{0, 0}
 };
 
@@ -59,14 +71,14 @@ static ht_mask_ptable metadata_section[] = {
 	{0, 0}
 };
 
-static ht_view *htpeil_init(bounds *b, ht_streamfile *file, ht_format_group *group)
+static ht_view *htpeil_init(Bounds *b, File *file, ht_format_group *group)
 {
 	ht_pe_shared_data *pe_shared=(ht_pe_shared_data *)group->get_shared_data();
 
 	if (pe_shared->opt_magic!=COFF_OPTMAGIC_PE32) return NULL;
 
-	dword sec_rva, sec_size;
-	FILEOFS sec_ofs;
+	uint32 sec_rva, sec_size;
+	FileOfs sec_ofs;
 	sec_rva = pe_shared->pe32.header_nt.directory[PE_DIRECTORY_ENTRY_IL].address;
 	sec_size = pe_shared->pe32.header_nt.directory[PE_DIRECTORY_ENTRY_IL].size;
 	if (!sec_rva || !sec_size) return NULL;
@@ -80,89 +92,87 @@ static ht_view *htpeil_init(bounds *b, ht_streamfile *file, ht_format_group *gro
 	file->seek(sec_ofs);
 	if (file->read(&dir, sizeof dir) != sizeof dir) goto read_error;
 
-	create_host_struct(&dir, PE_IL_DIRECTORY_struct, little_endian);
+	createHostStruct(&dir, PE_IL_DIRECTORY_struct, little_endian);
 	
 	if (sec_size != dir.size) goto read_error;
 	
 	pe_shared->il = new ht_pe_il();
 	pe_shared->il->dir = dir;
 
-	v=new ht_pe_il_viewer();
+	v = new ht_pe_il_viewer();
 	v->init(b, DESC_PE_IL, VC_EDIT | VC_SEARCH, file, group);
 	pe_shared->v_il = v;
 	ht_mask_sub *s;
 //	ht_collapsable_sub *cs;
 	
-	s=new ht_mask_sub();
+	s = new ht_mask_sub();
 	s->init(file, 0);
 	char info[128];
-	ht_snprintf(info, sizeof info, "* COM+ directory at offset %08x", sec_ofs);
+	ht_snprintf(info, sizeof info, "* COM+ directory at offset %08qx", sec_ofs);
 	s->add_mask(info);
 	v->insertsub(s);
 
-/* FIXME: */
+	/* FIXME: */
 	
 	s=new ht_mask_sub();
 	s->init(file, 1);
 	s->add_staticmask_ptable(il_directory, sec_ofs, pe_bigendian);
 	v->insertsub(s);
 	
-	FILEOFS metadata_ofs;
+	FileOfs metadata_ofs;
 	if (pe_rva_to_ofs(&pe_shared->sections, dir.metadata_section_rva, &metadata_ofs)) {
 		/* read metadata section*/
 		IL_METADATA_SECTION metadata;
 		file->seek(metadata_ofs);
 		if (file->read(&metadata, sizeof metadata) == sizeof metadata) {
-			create_host_struct(&metadata, IL_METADATA_SECTION_struct, little_endian);
+			createHostStruct(&metadata, IL_METADATA_SECTION_struct, little_endian);
 			pe_shared->il->metadata = metadata;
-			dword add = 2;
+			uint32 add = 2;
 			if (metadata.minor_version == 1) {
 				// FIXME: align metadata.version_string_length
-				dword version_string_length;
+				uint32 version_string_length;
 				file->read(&version_string_length, 4); // dummy
 				file->read(&version_string_length, 4);
-				version_string_length = create_host_int(&version_string_length, 4, little_endian);
+				version_string_length = createHostInt(&version_string_length, 4, little_endian);
 				add += version_string_length + 8;
 			}
-			FILEOFS ofs = metadata_ofs + sizeof metadata + add;
+			FileOfs ofs = metadata_ofs + sizeof metadata + add;
 			file->seek(ofs);
-			word count;
+			uint16 count;
 			file->read(&count, 2);
-			count = create_host_int(&count, 2, little_endian);
-			pe_shared->il->entries = new ht_clist();
-			pe_shared->il->entries->init();
-			for (UINT i=0; i<count; i++) {
+			count = createHostInt(&count, 2, little_endian);
+			pe_shared->il->entries = new Array(true);
+			for (uint i=0; i < count; i++) {
 				IL_METADATA_SECTION_ENTRY sec_entry;
 				ht_il_metadata_entry *entry;
 				// FIXME: error handling
 				file->read(&sec_entry, sizeof sec_entry);
-				create_host_struct(&sec_entry, IL_METADATA_SECTION_ENTRY_struct, little_endian);
-				char *name = fgetstrz(file);
-				int nlen = strlen(name)+1;
-				dword dummy;
+				createHostStruct(&sec_entry, IL_METADATA_SECTION_ENTRY_struct, little_endian);
+				String name("?");
+				file->readStringz(name);
+				int nlen = name.length() + 1;
+				uint32 dummy;
 				if (nlen % 4) {
 					// align properly
 					file->read(&dummy, 4 - nlen % 4);
 				}
-				entry = new ht_il_metadata_entry(name, metadata_ofs+sec_entry.offset, sec_entry.size);
-//				fprintf(stderr, "%s %x %x\n", name, metadata_ofs+sec_entry.offset, sec_entry.size);
+				entry = new ht_il_metadata_entry(name.contentChar(), metadata_ofs+sec_entry.offset, sec_entry.size);
+//				fprintf(stderr, "%s %x %x\n", name.contentChar(), metadata_ofs+sec_entry.offset, sec_entry.size);
 				pe_shared->il->entries->insert(entry);
-
-				free(name);
 			}
-			for (UINT i=0; i<count; i++) {
-				ht_il_metadata_entry *entry = (ht_il_metadata_entry *)pe_shared->il->entries->get(i);
+			for (uint i=0; i<count; i++) {
+				ht_il_metadata_entry *entry = (ht_il_metadata_entry *)(*pe_shared->il->entries)[i];
 				if (strcmp(entry->name, "#~") == 0) {
 					// token index
 					char dummy[8];
-					qword types;
+					uint64 types;
 					file->seek(entry->offset);
 					file->read(&dummy, 8);
 					file->read(&types, 8);
 //					file->read();
 				} else if (strcmp(entry->name, "#US")==0) {
 					// stringpool
-					pe_shared->il->string_pool = (char*)malloc(entry->size);
+					pe_shared->il->string_pool = ht_malloc(entry->size);
 					file->seek(entry->offset);
 					pe_shared->il->string_pool_size = file->read(pe_shared->il->string_pool, entry->size);
 				}
@@ -185,7 +195,7 @@ format_viewer_if htpeil_if = {
  *	CLASS ht_pe_header_viewer
  */
 
-void ht_pe_il_viewer::init(bounds *b, char *desc, int caps, ht_streamfile *file, ht_format_group *group)
+void ht_pe_il_viewer::init(Bounds *b, const char *desc, int caps, File *file, ht_format_group *group)
 {
 	ht_uformat_viewer::init(b, desc, caps, file, group);
 	VIEW_DEBUG_NAME("ht_pe_il_viewer");
@@ -195,17 +205,14 @@ void ht_pe_il_viewer::done()
 {
 	ht_pe_shared_data *pe_shared=(ht_pe_shared_data *)format_group->get_shared_data();
 	if (pe_shared && pe_shared->il) {
-		if (pe_shared->il->string_pool) free(pe_shared->il->string_pool);
-		if (pe_shared->il->entries) {
-		    pe_shared->il->entries->destroy();
-		    delete pe_shared->il->entries;
-		}
+		free(pe_shared->il->string_pool);
+		delete pe_shared->il->entries;
 		delete pe_shared->il;
 	}
 	ht_uformat_viewer::done();
 }
 
-ht_il_metadata_entry::ht_il_metadata_entry(char *n, dword o, dword s)
+ht_il_metadata_entry::ht_il_metadata_entry(const char *n, uint32 o, uint32 s)
 {
 	name = ht_strdup(n);
 	offset = o;
@@ -220,7 +227,7 @@ ht_il_metadata_entry::~ht_il_metadata_entry()
 /*
  *	NOTE: ILunpack returns result in host-endianess
  */
-int ILunpackDword(dword &result, const byte *buf, int len)
+int ILunpackDword(uint32 &result, const byte *buf, int len)
 {
 	if (len) {
 		result = *(buf++);
@@ -235,28 +242,28 @@ int ILunpackDword(dword &result, const byte *buf, int len)
 			// four byte form
 			if (len < 2) return 0;
 			result = ((result & 0x1F) << 24) |
-				    (((dword)buf[0]) << 16) |
-				    (((dword)buf[1]) << 8) |
-					 (dword)buf[2];
+				    (((uint32)buf[0]) << 16) |
+				    (((uint32)buf[1]) << 8) |
+					 (uint32)buf[2];
 			return 4;
 		} else if ((result & 0xf0) == 0xe0) {
 			// five byte form
 			if (len < 3) return 0;
-			result = (((dword)buf[0]) << 24) |
-				    (((dword)buf[1]) << 16) |
-				    (((dword)buf[2]) << 8) |
-					 (dword)buf[3];
+			result = (((uint32)buf[0]) << 24) |
+				    (((uint32)buf[1]) << 16) |
+				    (((uint32)buf[2]) << 8) |
+					 (uint32)buf[3];
 			return 5;
 		}
 	}
 	return 0;
 }
 
-int ILunpackToken(dword &result, const byte *buf, int len)
+int ILunpackToken(uint32 &result, const byte *buf, int len)
 {
 	int read = ILunpackDword(result, buf, len);
 	if (!read) return 0;
-	dword type;
+	uint32 type;
 	switch (result & 0x03) {
 		case 0x00:
 			type = IL_META_TOKEN_TYPE_DEF;
