@@ -34,8 +34,8 @@ class ht_xbe_aviewer: public ht_aviewer {
 public:
 	ht_xbe_shared_data *xbe_shared;
 
-		void init(bounds *b, char *desc, int caps, ht_streamfile *file, ht_format_group *format_group, Analyser *Analyser, ht_xbe_shared_data *xbe_shared);
-	virtual int  func_handler(eval_scalar *result, char *name, eval_scalarlist *params);
+		void init(Bounds *b, const char *desc, int caps, File *file, ht_format_group *format_group, Analyser *Analyser, ht_xbe_shared_data *xbe_shared);
+	virtual bool func_handler(eval_scalar *result, char *name, eval_scalarlist *params);
 	virtual void setAnalyser(Analyser *a);
 };
 
