@@ -113,7 +113,7 @@ static void load_file(char *fn, uint mode)
 	cwd[0] = 0;
 	getcwd(cwd, sizeof cwd);
 
-	if (sys_common_canonicalize(cfn, fn, cwd, sys_is_path_delim)==0) {
+	if (sys_common_canonicalize(cfn, sizeof cfn, fn, cwd, sys_is_path_delim)==0) {
 		add_file_history_entry(cfn);
 		((ht_app*)app)->create_window_file(cfn, mode, true);
 	}
@@ -300,7 +300,8 @@ int main(int argc, char *argv[])
 		case LS_OK:
 			break;
 		case LS_ERROR_NOT_FOUND:
-			LOG_EX(LOG_WARN, "couldn't load configuration file, using defaults");
+			LOG_EX(LOG_WARN, "no configuration file found, using defaults");
+			LOG_EX(LOG_WARN, "note that %s has no mouse support. Use the keyboard!", ht_name);
 			break;
 		case LS_ERROR_READ:
 			LOG_EX(LOG_ERROR, "couldn't read configuration file...");
