@@ -69,56 +69,56 @@
  */
 
 struct ImageSymHeader {
-	dword file_size HTPACKED;		// in 16-byte blocks
-	word entry_seg HTPACKED;
-	word u0 HTPACKED;				// 0000
-	word u1 HTPACKED;				// 0015 (some flags ?, 0014 for 16-bit .SYM ?)
-	word seg_count HTPACKED;
-	dword u2 HTPACKED;				// 04020002 (some flags ?)
-	byte	module_name[16] HTPACKED;
-};
+	uint32 file_size;		// in 16-byte blocks
+	uint16 entry_seg;
+	uint16 u0;				// 0000
+	uint16 u1;				// 0015 (some flags ?, 0014 for 16-bit .SYM ?)
+	uint16 seg_count;
+	uint32 u2;				// 04020002 (some flags ?)
+	byte	module_name[16];
+} PACKED;
 
 struct ImageSymSegHeader {
-	word next_rec_ofs HTPACKED;		// in 16-byte blocks (ring list, last points to first)
-	word sym_count HTPACKED;
-	word sym_ptr_table_ptr HTPACKED;
-	word seg_idx HTPACKED;
-	dword seg_start HTPACKED;
-	dword seg_size HTPACKED;
-};
+	uint16 next_rec_ofs;		// in 16-byte blocks (ring list, last points to first)
+	uint16 sym_count;
+	uint16 sym_ptr_table_ptr;
+	uint16 seg_idx;
+	uint32 seg_start;
+	uint32 seg_size;
+} PACKED;
 
 struct ImageSymDescriptor {
-	dword address HTPACKED;
-//	byte  name_len HTPACKED;
+	uint32 address;
+//	byte  name_len;
 //   name;
 //   ^^^^ pascal string
-};
+} PACKED;
 
 /*
  *
  */
 
 #define MAX_BYTES_PER_SEGMENT		0xff00
-#define MAX_SYMBOLS_PER_SEGMENT	0x4000
+#define MAX_SYMBOLS_PER_SEGMENT		0x4000
 
-static void write_sym(ht_stream *stream, dword addr, char *name, UINT *bytes_written)
+static void write_sym(Stream &stream, uint32 addr, const char *name, uint *bytes_written)
 {
 	ImageSymDescriptor desc;
 	desc.address = addr;
-	stream->write(&desc, sizeof desc); // FIXME: endianess !
-	putstrp(stream, name);
+	stream.write(&desc, sizeof desc); // FIXME: endianess !
+	stream.writestrp(name);
 	*bytes_written += sizeof desc + 1 + strlen(name);
 }
 
-static void g(ht_stream *stream, Symbol *s, UINT *bytes_written, UINT *symbols_written, word *ptr_table)
+static void g(Stream &stream, Symbol *s, uint *bytes_written, uint *symbols_written, uint16 *ptr_table)
 {
 	if (*bytes_written >= MAX_BYTES_PER_SEGMENT) return;
 	if (*symbols_written >= MAX_SYMBOLS_PER_SEGMENT) return;
 
-	dword addr;
+	uint32 addr;
 	if (s->location->addr->byteSize() == sizeof addr) {
 		s->location->addr->putIntoArray((byte*)&addr);
-//          addr -= 0xbff70000;	/* FIXME: hack for kernel32.dll */
+//		addr -= 0xbff70000;	/* FIXME: hack for kernel32.dll */
 	} else {
 		addr = 0;
 	}
@@ -129,7 +129,7 @@ static void g(ht_stream *stream, Symbol *s, UINT *bytes_written, UINT *symbols_w
 	(*symbols_written) ++;
 }
 
-static void align16(ht_streamfile *file, UINT *bytes_written)
+static void align16(File *file, uint *bytes_written)
 {
 	byte c = 0;
 	while (*bytes_written % 16) {
@@ -138,12 +138,12 @@ static void align16(ht_streamfile *file, UINT *bytes_written)
 	}
 }
  
-int export_to_sym(Analyser *analy, ht_streamfile *file)
+int export_to_sym(Analyser *analy, File *file)
 {
 	if ((!analy) || (!file)) return /*HTML_OUTPUT_ERR_GENERIC*/1;
 	if (analy->active) return /*HTML_OUTPUT_ERR_ANALY_NOT_FINISHED*/1;
 
-	char *module_name = "TEST";
+	const char *module_name = "TEST";
 	ImageSymHeader head;
 	ImageSymSegHeader seg_head;
 
@@ -158,18 +158,18 @@ int export_to_sym(Analyser *analy, ht_streamfile *file)
 	memset(&seg_head, 0, sizeof seg_head);
 	file->write(&seg_head, sizeof seg_head);
 
-	UINT bytes_written = sizeof seg_head, symbols_written = 0;
+	uint bytes_written = sizeof seg_head, symbols_written = 0;
 
-	write_sym(file, 0xff000000, "_TEXT", &bytes_written);
+	write_sym(*file, 0xff000000, "_TEXT", &bytes_written);
 
-	word *ptr_table = (word*)malloc(MAX_SYMBOLS_PER_SEGMENT * sizeof *ptr_table);
+	uint16 *ptr_table = ht_malloc(MAX_SYMBOLS_PER_SEGMENT * sizeof *ptr_table);
 
 	Symbol *sym = NULL;
 	while ((sym = analy->enumSymbols(sym))) {
-		g(file, sym, &bytes_written, &symbols_written, ptr_table);
+		g(*file, sym, &bytes_written, &symbols_written, ptr_table);
 	}
 	
-	UINT sym_ptr_table_ptr = bytes_written;
+	uint sym_ptr_table_ptr = bytes_written;
 
 	// FIXME: endianess !
 	file->write(ptr_table, sizeof *ptr_table * symbols_written);
@@ -179,7 +179,7 @@ int export_to_sym(Analyser *analy, ht_streamfile *file)
 	align16(file, &bytes_written);
 
 	// FIXME: wrong code order, endianess !
-	dword terminator = 0x04000000;
+	uint32 terminator = 0x04000000;
 	file->write(&terminator, sizeof terminator);
 	bytes_written += 4;
 
